@@ -91,16 +91,18 @@ public class MailWs {
 		return result;
 	}
 
-	private Store getIMAPStore(String host, String user, String password) throws MessagingException {
-		Properties props = System.getProperties();
-		imap_session = Session.getDefaultInstance(props, null);
-		imap_store = imap_session.getStore("imap");
-		imap_store.connect(host, user, password);
+	private Store getIMAPStore(MailSetting mailSetting) throws MessagingException {
+		if (imap_store == null || !imap_store.isConnected()) {
+			Properties props = System.getProperties();
+			imap_session = Session.getDefaultInstance(props, null);
+			imap_store = imap_session.getStore(mailSetting.getProviderName());
+			imap_store.connect(mailSetting.getImapHost(), mailSetting.getImapLoginid(), mailSetting.getImapPassword());
+		}
 		return imap_store;
 	}
 
-	public Folder getInbox(String host, String user, String password) throws MessagingException {
-		Store store = getIMAPStore(host, user, password);
+	public Folder getInbox(MailSetting mailSetting) throws MessagingException {
+		Store store = getIMAPStore(mailSetting);
 	    Folder[] root = null;
 		root = store.getDefaultFolder().list("INBOX");
 		return root[0];
@@ -152,19 +154,26 @@ public class MailWs {
 		return src;
 	}
 
-    private static String getTextMessage(Object content)
+	
+    /**
+     * @param content
+     * @return String[] 0Ԗڂ̗vfFRec^CvA1Ԗڂ̗vfF{
+     * @throws javax.mail.MessagingException
+     * @throws java.io.IOException
+     */
+    private static String[] getTextMessage(Object content)
 			throws javax.mail.MessagingException, java.io.IOException {
 		if (content instanceof String) {
-			return content.toString().indexOf(0x1b) >= 0 
-				? new String(content.toString().getBytes("8859_1"), "ISO2022JP") : content.toString();
+			return new String[] {"TEXT/PLAIN", content.toString().indexOf(0x1b) >= 0 
+				? new String(content.toString().getBytes("8859_1"), "ISO2022JP") : content.toString()};
 		} else {
 			Multipart part = (Multipart) content;
 			for (int i = 0; i < part.getCount(); i++) {
 				BodyPart body = part.getBodyPart(i);
 				String ctype = body.getContentType().toUpperCase();
-				if (ctype.startsWith("TEXT/PLAIN"))
-					return body.getContent().toString().indexOf(0x1b) >= 0 
-						? new String(body.getContent().toString().getBytes("8859_1"), "ISO2022JP") : body.getContent().toString();
+				if (ctype.startsWith("TEXT/PLAIN") || ctype.startsWith("TEXT/HTML"))
+					return new String[] {ctype, body.getContent().toString().indexOf(0x1b) >= 0 
+						? new String(body.getContent().toString().getBytes("8859_1"), "ISO2022JP") : body.getContent().toString()};
 				if (body.getContent() instanceof Multipart) {
 					return getTextMessage(body.getContent());
 				}
@@ -175,7 +184,7 @@ public class MailWs {
     
     public Folder getTargetFolder(Member loginMember, int mailSettingId, String folderName) throws MessagingException {
     	MailSetting setting = getMailSetting(loginMember.getId(), mailSettingId);
-		Folder inbox = getInbox(setting.getImapHost(), setting.getImapLoginid() , setting.getImapPassword());
+		Folder inbox = getInbox(setting);
 		Folder target = null;
 		if (folderName.equals("INBOX")) {
 			target = inbox;
@@ -191,7 +200,7 @@ public class MailWs {
         String[] results = new String[addrs.length];
         for (int i = 0; i < addrs.length; i++) {
         	try {
-        		results[i] = MimeUtility.decodeText(addrs[i].toString());
+        		results[i] = decodeMime(addrs[i].toString());
 		    } catch (Exception ex) {
 		    	results[i] = addrs[i].toString();
 		    }
@@ -230,7 +239,9 @@ public class MailWs {
 	     
 	     if (containBody) {
 		     try {
-		         mail.setBody(getTextMessage(msg.getContent()));
+		    	 String[] body = getTextMessage(msg.getContent());
+		         mail.setContentType(body[0]);
+		         mail.setBody(body[1]);
 		     } catch (Exception ex) {
 		    	 mail.setBody("");
 		     }
@@ -277,6 +288,7 @@ public class MailWs {
 			return result;
 		} finally {
 			target.close(false);
+			imap_store.close();
 		}
     }
     
@@ -315,6 +327,7 @@ public class MailWs {
 			target.close(false);
 		}
 		result.setResult(resMails);
+		imap_store.close();
 		return result;
 	}
     
@@ -393,7 +406,7 @@ public class MailWs {
 		}
     	Transport.send(new_msg);
         String sended = setting.getMailSendedFolder();
-		if (!StringUtils.isEmpty(sended)) {
+		if (setting.getProtocol() == MailSetting.PROTOCOL_IMAP && !StringUtils.isEmpty(sended)) {
 			Folder sended_mbox = getTargetFolder(loginMember, mailSettingId, sended);
 			if (sended_mbox.exists()) {
 				new_msg.setSentDate(new Date());
@@ -419,16 +432,20 @@ public class MailWs {
 		if (!loginMember.isLogined(result)) {
 			return result;
 		}
+		MailSetting setting = getMailSetting(loginMember.getId(), mailSettingId);
 		Folder folder_from = getTargetFolder(loginMember, mailSettingId, folderName);
-		Folder folder_to = getTargetFolder(loginMember, mailSettingId, "Trash");
-		if (folder_to != null && !folder_to.exists()) {
-			result.setStatusCode(1);
-			return result;
+		Folder folder_to = null;
+		if (setting.getProtocol() == MailSetting.PROTOCOL_IMAP) {
+			folder_to = getTargetFolder(loginMember, mailSettingId, "Trash");
+			if (folder_to != null && !folder_to.exists()) {
+				result.setStatusCode(1);
+				return result;
+			}
 		}
 		try {
 			folder_from.open(Folder.READ_WRITE);
 			Message[] msgs = msgId2MsgNo(folder_from, msgIds);
-			if (folder_to != null
+			if (setting.getProtocol() == MailSetting.PROTOCOL_IMAP && folder_to != null
 				&& !folder_from.getName().equals(folder_to.getName())) {
 				folder_to.open(Folder.READ_WRITE);
 				folder_from.copyMessages(msgs, folder_to);
@@ -442,6 +459,7 @@ public class MailWs {
 				folder_to.close(false);
 		}
 		result.setResult(msgIds);
+		imap_store.close();
 		return result;
 	}
 
